gchecky.model.price_t

Package gchecky :: Module model :: Class price_t |
[hide private]
[frames] | no frames]

# Class price_t

source code

    object --+
             |
     gxml.Node --+
                 |
                price_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| value = `Double:PATH():REQ`
| currency = `String:PATH(@currency):REQ:EMPTY:VALS("USD","GBP")`
| _fields = ``{``'``currency``'``:` String:PATH(@currency):REQ:EMPTY:VALS("`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'currency': String:PATH(@currency):REQ:EMPTY:VALS("USD","GBP"),
       'value': Double:PATH():REQ}